#
# spec file for package ipvsadm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           ipvsadm
BuildRequires:  kernel-source
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
Summary:        A Utility for Administering the Linux Virtual Server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
Version:        1.31
Release:        3.6
URL:            http://www.linuxvirtualserver.org/
Source0:        https://www.kernel.org/pub/linux/utils/kernel/ipvsadm/%{name}-%{version}.tar.xz
Source1:        ipvsadm.service
Patch0:         ipvsadm-makefile.patch
Patch1:         ipvsadm-print_largenum.patch
Provides:       %{name}-%{version}
Requires:       grep
Requires(pre):  %fillup_prereq
%{?systemd_requires}

%description
ipvsadm is a utility for administering the IP virtual server services
offered by the Linux kernel with Linux Virtual Server support.

%prep
%autosetup
# This files are embedded here instead of being another source in order
# to the prefix directory
cat >sysconfig.ipvsadm <<EOFF
## Path:           Network/IPVS
## Description:    Linux Virtual Server Configuration
## ServiceRestart: ipvsadm
## Type:           string
## Default:        /etc/ipvsadm.rules
#
# Where to find the IPVSADM config-file
#
IPVSADM_CONFIG="/etc/ipvsadm.rules"
EOFF
cat >ipvsadm.rules <<EOFF
#
# Please insert your ipvs-rules here
#
EOFF

%build
make POPT_LIB="-lpopt" CFLAGS="%{optflags} -fPIC -DHAVE_POPT -DLIBIPVS_USE_NL -I%{_includedir}/libnl3"

%install
mkdir -p %{buildroot}/{sbin,%{_sbindir},%{_mandir}/man8,%{_unitdir},%{_fillupdir}}
make BUILD_ROOT=%{buildroot} MANDIR=%{_mandir} SBINDIR=%{_sbindir} install
%if 0%{?suse_version} < 1550
for binary in ipvsadm ipvsadm-save ipvsadm-restore ; do
  ln -sf %{_sbindir}/$binary            %{buildroot}/sbin/$binary ;
done
%endif
# Sysvinit support dropping
rm -rf %{buildroot}/etc/init.d
# install SuSE init script
install -m 644 %{S:1}           	%{buildroot}%{_unitdir}/%{name}.service
ln -sf %_sbindir/service	        %{buildroot}%{_sbindir}/rc%{name}
install -m 644 sysconfig.ipvsadm	%{buildroot}%{_fillupdir}/sysconfig.%{name}
install -m 644 ipvsadm.rules		%{buildroot}%{_sysconfdir}/%{name}.rules

%post
%{fillup_only}
%service_add_post ipvsadm.service

%postun
%service_del_postun ipvsadm.service

%pre
%service_add_pre ipvsadm.service

%preun
%service_del_preun ipvsadm.service

%files
%defattr(-,root,root)
%doc README
%config %{_sysconfdir}/%{name}.rules
%{_unitdir}/%{name}.service
%if 0%{?suse_version} < 1550
/sbin/ipvsadm*
%endif
%{_sbindir}/ipvsadm*
%{_sbindir}/rcipvsadm*
/%{_mandir}/man*/ipvsadm*
%{_fillupdir}/sysconfig.%{name}

%changelog
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Sep  6 2022 Marius Tomaschewski <mt@suse.com>
- Finish UsrMerge and move binaries /usr/sbin (bsc#1191064)
- Re-add changes to zero-byte ipvsadm-print_largenum.patch file
* Sat Apr 23 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.31
  * This release add support for configuring tunneling with
    GRE or GUE encapsulation. See manpage ipvsadm(8) for --tun-type
    and --tun-info, plus more specific --tun-xxxx options for adjustments.
  * Some manpage adjustments.
- Update to version 1.30
  * Adding the missing userspace side for the schedulers MH, FO and OVF.
- Replaced and rebased ipvsadm-1.26.diff and ipvsadm-PIE.patch with
  ipvsadm-makefile.patch
- Rebased ipvsadm-print_largenum.diff as ipvsadm-print_largenum.patch
* Mon Apr 19 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Hardening: link as position independent executable (bsc#1184988).
  ipvsadm-PIE.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Jan  5 2017 p.drouand@gmail.com
- Update to version 1.29
  * No changelog available
* Tue Dec 20 2016 mt@suse.de
- fixed systemd service file to restore correct config file at
  start (/etc/ipvsadm.rules) and do not break boot-time config
  at stop (bsc#1013581).
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 1.28
  * No changelog available
- Update download Url
- Remove obsolete patches
  * 03_libnl-3-linking.patch
  * ipvsadm-1.26-ipvs_dests_parse_cb-memory-corruption.diff
  * ipvsadm-1.26-wrong-error-with--ops-option.bnc847005.diff
- Update ipvsadm-1.26-print_largenum.diff > ipvsadm-print_largenum.diff
* Wed May 28 2014 crrodriguez@opensuse.org
- 03_libnl-3-linking.patch from debian, allow use of libnl3
  instead of libnl1
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu Feb 13 2014 mt@suse.de
- Fix segfault when running 'ipvsadm -Ln' caused by buffer overrun
  in ipvs_dests_parse_cb() function (bnc#775051), by Tim Serong.
  [+ ipvsadm-1.26-ipvs_dests_parse_cb-memory-corruption.diff]
- Fix wrong error message when using ipvsadm with option "--ops"
  (bnc#847005), by Paul Zirnik.
  [+ ipvsadm-1.26-wrong-error-with--ops-option.bnc847005.diff]
* Mon Oct 28 2013 p.drouand@gmail.com
- Add systemd support and drop sysvinit support
- Remove AUTHORS section
- Remove redundant %%clean section
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Tue Feb  8 2011 mt@suse.de
- Updated to ipvsadm-1.26 (for kernel 2.6.28-rc3 or later)
  adding IPv6 support, netlink interface and code cleanups.
- Adopted patches and spec file, switched to use new netlink
  interface and popt (getopt support dropped).
- Fixed rpmlint warnings in the init script and spec file.
* Mon Aug 25 2008 mt@suse.de
- init script: copy LSB *-Start tags to *-Stop
* Sat May 27 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Wed Jan 28 2004 ro@suse.de
- update to 1.24
* Fri Sep 12 2003 ro@suse.de
- configure kernel-source if needed
* Tue Aug 19 2003 mt@suse.de
- added "ServiceRestart: ipvsadm" yast2 metadata
  to sysconfig file
* Fri Jan 31 2003 mt@suse.de
- added yast2 metadata variables to sysconfig file
* Wed Sep  4 2002 mt@suse.de
- fixed rpm group (Productivity/Networking/System)
- changed failed to skipped if not configured
- removed some echo prefixes and colons
- added rpm dependency to grep
* Mon Aug 19 2002 mmj@suse.de
- Correct PreReq
* Mon Aug  5 2002 ro@suse.de
- update to 1.21 to compile with current kernel
* Tue Jul 30 2002 ro@suse.de
- fix patch
* Fri Jul 19 2002 mt@suse.de
- updated to ipvsadm-1.20
- enabled getopt usage, since newer popt is needed
* Mon Jan 14 2002 ro@suse.de
- removed START_IPVSADM
* Fri Jul 27 2001 mt@suse.de
- fixed popt dependency
- fixed init script to be LSB complaient
* Fri Apr 27 2001 mge@suse.de
- initial SuSE RPM
